:orphan:

.. currentmodule:: xdggs

.. autosummary::
   :toctree: generated

   DGGSInfo.level

   DGGSInfo.from_dict
   DGGSInfo.to_dict
   DGGSInfo.cell_boundaries
   DGGSInfo.cell_ids2geographic
   DGGSInfo.geographic2cell_ids

   HealpixInfo.level
   HealpixInfo.indexing_scheme
   HealpixInfo.valid_parameters
   HealpixInfo.nside
   HealpixInfo.nest

   HealpixInfo.from_dict
   HealpixInfo.to_dict
   HealpixInfo.cell_boundaries
   HealpixInfo.cell_ids2geographic
   HealpixInfo.geographic2cell_ids

   H3Info.level
   H3Info.valid_parameters

   H3Info.from_dict
   H3Info.to_dict
   H3Info.cell_boundaries
   H3Info.cell_ids2geographic
   H3Info.geographic2cell_ids
